@@ -122,9 +122,9 @@ public:
         return ret;
     }
 
-    int size() override
+    quint64 size() override
     {
-        int ret = 0;
+        quint64 ret = 0;
         const auto resources = withoutDuplicates();
         for (auto res : resources) {
             ret += res->size();
@@ -391,6 +391,10 @@ void PackageKitUpdater::start()
 
     setupTransaction(PackageKit::Transaction::TransactionFlagSimulate);
     setProgressing(true);
+
+    if (useOfflineUpdates()) {
+        enableNeedsReboot();
+    }
 }
 
 void PackageKitUpdater::finished(PackageKit::Transaction::Exit exit, uint /*time*/)
@@ -549,8 +553,10 @@ void PackageKitUpdater::cancel()
 
 void PackageKitUpdater::errorFound(PackageKit::Transaction::Error err, const QString &error)
 {
-    if (err == PackageKit::Transaction::ErrorNoLicenseAgreement)
+    if (err == PackageKit::Transaction::ErrorNoLicenseAgreement || err == PackageKit::Transaction::ErrorTransactionCancelled
+        || err == PackageKit::Transaction::ErrorNotAuthorized) {
         return;
+    }
     QString finalMessage = xi18nc("@info", "%1:<nl/><nl/>%2", PackageKitMessages::errorMessage(err), error);
     Q_EMIT passiveMessage(finalMessage);
     qWarning() << "Error happened" << err << error;
